@@ -125,3 +125,6 @@ class TranslatorTags(GXIntEnum):
     RESPONSE_ALLOWED = 0xFF82
     EXCEPTION_RESPONSE = 0xFF83
     STATE_ERROR = 0xFF84
+    P_BLOCK = 0xFF85
+    CONTENT = 0xFF86
+    SIGNATURE = 0xFF87
