@@ -78,7 +78,7 @@ class GXDLMSPrimeNbOfdmPlcMacNetworkAdministrationData(GXDLMSObject, IGXDLMSBase
 
     def reset(self, client):
         """Reset the values."""
-        return client.method(self.getName(), self.objectType, 1, 0, DataType.INT8)
+        return client.method(self, 1, 0, DataType.INT8)
 
     def invoke(self, settings, e):
         #  Resets the value to the default value.
